svd

Function svd 

pub fn svd<T: ComplexField>(
    A: MatRef<'_, T>,
    s: DiagMut<'_, T>,
    u: Option<MatMut<'_, T>>,
    v: Option<MatMut<'_, T>>,
    par: Par,
    stack: &mut MemStack,
    params: Spec<SvdParams, T>,
) -> Result<(), SvdError>
computes the svd of $A$, with the singular vectors being omitted, thin or full

the singular are stored in $S$, and the singular vectors in $U$ and $V$ such that the singular values are sorted in nonincreasing order